==> appops-br-service-base-0.3.0-sources.jar: org/appops/service/deployment/DeploymentOrchestrator.java <==
/*
 * AppOps is a Java framework to develop, deploy microservices with ease and is available for free
 * and common use developed by AinoSoft ( www.ainosoft.com )
 *
 * AppOps and AinoSoft are registered trademarks of Aino Softwares private limited, India.
 *
 * Copyright (C) <2016> <Aino Softwares private limited>
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version along with applicable additional terms as
 * provisioned by GPL 3.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License and applicable additional terms
 * along with this program.
 *
 * If not, see <https://www.gnu.org/licenses/> and <https://www.appops.org/license>
 */

package org.appops.service.deployment;

import java.util.Map;
import org.appops.core.deployment.DeploymentConfig;
import org.appops.core.deployment.DeploymentMode;
import org.appops.core.service.ServiceConfig;

/**
 * <p>
 * DeploymentOrchestrator class.
 * </p>
 *
 * @author deba
 * @version $Id: $Id
 */
public class DeploymentOrchestrator {


  /**
   * <p>
   * deploy.
   * </p>
   *
   * @param deployment a {@link org.appops.core.deployment.DeploymentConfig} object.
   */
  public void deploy(DeploymentConfig deployment) {
    DeploymentMode mode = deployment.getMode();
    startServices(deployment.getServices());
  }

  private void startServices(Map<String, ServiceConfig> services) {
    for (String service : services.keySet()) {
      ServiceConfig config = services.get(service);

    }
  }

}

==> appops-br-service-base-0.5.0-sources.jar: org/appops/service/deployment/DeploymentOrchestrator.java <==
/*
 * AppOps is a Java framework to develop, deploy microservices with ease and is available for free
 * and common use developed by AinoSoft ( www.ainosoft.com )
 *
 * AppOps and AinoSoft are registered trademarks of Aino Softwares private limited, India.
 *
 * Copyright (C) <2016> <Aino Softwares private limited>
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version along with applicable additional terms as
 * provisioned by GPL 3.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License and applicable additional terms
 * along with this program.
 *
 * If not, see <https://www.gnu.org/licenses/> and <https://www.appops.org/license>
 *
 *
 */

package org.appops.service.deployment;

import java.util.Map;
import org.appops.core.deployment.DeploymentMode;
import org.appops.core.deployment.ServiceConfiguration;

/**
 * <p>
 * DeploymentOrchestrator class.
 * </p>
 *
 * @author deba
 * @version $Id: $Id
 */
@Deprecated
public class DeploymentOrchestrator {


  /**
   * <p>
   * deploy.
   * </p>
   *
   * @param deployment a {@link org.appops.core.deployment.DeploymentConfig} object.
   */
  public void deploy(ServiceConfiguration deployment) {
    DeploymentMode mode = deployment.getMode();
    // startServices(deployment.getServices());
  }

  private void startServices(Map<String, ServiceConfiguration> services) {
    for (String service : services.keySet()) {
      ServiceConfiguration config = services.get(service);

    }
  }

}
